pub fn from_slice<'a, T>(
b: &'a [u8],
format: LuaFormat,
max_depth: u16,
) -> Result<T, Error>where
T: Deserialize<'a>,Expand description
Parses a byte slice containing a Lua expression in format.
The Lua expression may only consist of simple data, with restrictions similar to JSON.
For more details about type mapping rules and parameters, see the crate docs.